@@ -40,9 +40,6 @@
 
 #include <libmate-desktop/mate-aboutdialog.h>
 #if GTK_CHECK_VERSION (3, 0, 0)
-#define MATE_DESKTOP_USE_UNSTABLE_API
-#include <libmate-desktop/mate-desktop-utils.h>
-#define gdk_spawn_command_line_on_screen mate_gdk_spawn_command_line_on_screen
 #define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
 #define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
 #endif
@@ -197,7 +194,12 @@ static void dialog_cb(GtkAction* action, AccessxStatusApplet* sapplet)
 						      &error);
 
 	if (!error) {
+#if GTK_CHECK_VERSION (3, 0, 0)
+		launch_context = gdk_display_get_app_launch_context (
+			               gtk_widget_get_display (GTK_WIDGET (screen)));
+#else
 		launch_context = gdk_app_launch_context_new ();
+#endif
 		gdk_app_launch_context_set_screen (launch_context, screen);
 		g_app_info_launch (appinfo, NULL, G_APP_LAUNCH_CONTEXT (launch_context), &error);
 
@@ -518,7 +520,11 @@ static GdkPixbuf* accessx_status_applet_slowkeys_image(AccessxStatusApplet* sapp
 			}
 		}
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+		fg = style->fg[gtk_widget_get_state_flags (GTK_WIDGET (sapplet->applet))];
+#else
 		fg = style->fg[gtk_widget_get_state(GTK_WIDGET(sapplet->applet))];
+#endif
 		glyph_pixbuf = accessx_status_applet_get_glyph_pixbuf(sapplet, GTK_WIDGET(sapplet->applet), ret_pixbuf, &fg, &bg, glyphstring);
 		gdk_pixbuf_composite(glyph_pixbuf, ret_pixbuf, 0, 0, gdk_pixbuf_get_width(glyph_pixbuf), gdk_pixbuf_get_height(glyph_pixbuf), 0., 0., 1.0, 1.0, GDK_INTERP_NEAREST, 255);
 		g_object_unref(glyph_pixbuf);
@@ -539,7 +545,11 @@ static GdkPixbuf* accessx_status_applet_bouncekeys_image(AccessxStatusApplet* sa
 
 	g_assert(sapplet->applet);
 	style = gtk_widget_get_style(GTK_WIDGET(sapplet->applet));
+#if GTK_CHECK_VERSION (3, 0, 0)
+	fg = style->text[gtk_widget_get_state_flags (GTK_WIDGET (sapplet->applet))];
+#else
 	fg = style->text[gtk_widget_get_state(GTK_WIDGET(sapplet->applet))];
+#endif
 	bg = style->base[GTK_STATE_NORMAL];
 
 	if (event != NULL)
@@ -648,12 +658,20 @@ static void accessx_status_applet_update(AccessxStatusApplet* sapplet, AccessxSt
 				if (locked_mods & modifiers[i].mask)
 				{
 					gtk_widget_set_sensitive(modifiers[i].indicator, TRUE);
+#if GTK_CHECK_VERSION (3, 0, 0)
+					gtk_widget_set_state_flags (modifiers[i].indicator, GTK_STATE_FLAG_SELECTED, TRUE);
+#else
 					gtk_widget_set_state(modifiers[i].indicator, GTK_STATE_SELECTED);
+#endif
 				}
 				else if (latched_mods & modifiers[i].mask)
 				{
 					gtk_widget_set_sensitive(modifiers[i].indicator, TRUE);
+#if GTK_CHECK_VERSION (3, 0, 0)
+					gtk_widget_set_state_flags (modifiers[i].indicator, GTK_STATE_FLAG_NORMAL, TRUE);
+#else
 					gtk_widget_set_state(modifiers[i].indicator, GTK_STATE_NORMAL);
+#endif
 				}
 				else
 				{
@@ -788,7 +806,11 @@ static void accessx_status_applet_notify_xkb_device(AccessxStatusApplet* sapplet
 		if (event->led_state &= ALT_GRAPH_LED_MASK)
 		{
 			gtk_widget_set_sensitive(sapplet->alt_graph_indicator, TRUE);
+#if GTK_CHECK_VERSION (3, 0, 0)
+			gtk_widget_set_state_flags (sapplet->alt_graph_indicator, GTK_STATE_FLAG_NORMAL, TRUE);
+#else
 			gtk_widget_set_state(sapplet->alt_graph_indicator, GTK_STATE_NORMAL);
+#endif
 		}
 		else
 		{
@@ -881,7 +903,11 @@ static GtkIconSet* accessx_status_applet_altgraph_icon_set(AccessxStatusApplet*
 			case GTK_STATE_NORMAL:
 				alpha = 255;
 				gtk_widget_set_sensitive(widget, TRUE);
+#if GTK_CHECK_VERSION (3, 0, 0)
+				gtk_widget_set_state_flags (widget, GTK_STATE_FLAG_NORMAL, TRUE);
+#else
 				gtk_widget_set_state(widget, GTK_STATE_NORMAL);
+#endif
 				break;
 			case GTK_STATE_SELECTED:
 				/* FIXME: should use text/base here, for selected ? */
@@ -889,7 +915,11 @@ static GtkIconSet* accessx_status_applet_altgraph_icon_set(AccessxStatusApplet*
 				bg = &style->black;
 				alpha = 255;
 				gtk_widget_set_sensitive(widget, TRUE);
+#if GTK_CHECK_VERSION (3, 0, 0)
+				gtk_widget_set_state_flags (widget, GTK_STATE_FLAG_SELECTED, TRUE);
+#else
 				gtk_widget_set_state(widget, GTK_STATE_SELECTED);
+#endif
 				break;
 			case GTK_STATE_INSENSITIVE:
 			default:
@@ -921,7 +951,11 @@ static GtkIconSet* accessx_status_applet_altgraph_icon_set(AccessxStatusApplet*
 		gtk_icon_source_free(source);
 	}
 	/* we mucked about with the box's state to create the icons; restore it to normal */
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_widget_set_state_flags (widget, GTK_STATE_FLAG_NORMAL, TRUE);
+#else
 	gtk_widget_set_state(widget, GTK_STATE_NORMAL);
+#endif
 	gtk_widget_set_sensitive(widget, TRUE);
 
 	return icon_set;
